@@ -49,7 +49,7 @@ class InstanceIdTarget(
         :param instance_id: Instance ID of the instance to register to.
         :param port: Override the default port for the target group.
         '''
-        jsii.create(InstanceIdTarget, self, [instance_id, port])
+        jsii.create(self.__class__, self, [instance_id, port])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
@@ -95,7 +95,7 @@ class InstanceTarget(
         :param instance: Instance to register to.
         :param port: Override the default port for the target group.
         '''
-        jsii.create(InstanceTarget, self, [instance, port])
+        jsii.create(self.__class__, self, [instance, port])
 
 
 @jsii.implements(aws_cdk.aws_elasticloadbalancingv2.IApplicationLoadBalancerTarget, aws_cdk.aws_elasticloadbalancingv2.INetworkLoadBalancerTarget)
@@ -141,7 +141,7 @@ class IpTarget(
         :param port: Override the group's default port.
         :param availability_zone: Availability zone to send traffic from.
         '''
-        jsii.create(IpTarget, self, [ip_address, port, availability_zone])
+        jsii.create(self.__class__, self, [ip_address, port, availability_zone])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
@@ -182,7 +182,7 @@ class LambdaTarget(
 
         :param fn: -
         '''
-        jsii.create(LambdaTarget, self, [fn])
+        jsii.create(self.__class__, self, [fn])
 
     @jsii.member(jsii_name="attachToApplicationTargetGroup")
     def attach_to_application_target_group(
